@@ -1,5 +1,4 @@
-use graplot::{Scatter, Plot};
-
+use graplot::Scatter;
 
 #[test]
 fn test_scatter() {
@@ -7,6 +6,12 @@ fn test_scatter() {
     let y = [99.,86.,87.,88.,111.,86.,70.,87.,94.,78.,77.,85.,86.];
 
     let mut scat = Scatter::new((x, y));
-    scat.add(Plot::new(([3., 16.], [30., 150.], "r-")));
+    
+    scat.plot.set_desc(graplot::Desc {
+        spacing_y: 80.,
+        ..Default::default()
+    });
+    
+    scat.add(([2., 10.5], [78., 114.], "r-"));
     scat.show();
 }
\ No newline at end of file
